# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: app/app/v1alpha/conversation.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from artifact.artifact.v1alpha import chunk_pb2 as artifact_dot_artifact_dot_v1alpha_dot_chunk__pb2
from google.api import field_behavior_pb2 as google_dot_api_dot_field__behavior__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\"app/app/v1alpha/conversation.proto\x12\x0f\x61pp.app.v1alpha\x1a%artifact/artifact/v1alpha/chunk.proto\x1a\x1fgoogle/api/field_behavior.proto\x1a\x1cgoogle/protobuf/struct.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"\x9e\x03\n\x0c\x43onversation\x12\x15\n\x03uid\x18\x01 \x01(\tB\x03\xe0\x41\x03R\x03uid\x12&\n\x0cnamespace_id\x18\x02 \x01(\tB\x03\xe0\x41\x02R\x0bnamespaceId\x12\x1a\n\x06\x61pp_id\x18\x03 \x01(\tB\x03\xe0\x41\x02R\x05\x61ppId\x12\x13\n\x02id\x18\x04 \x01(\tB\x03\xe0\x41\x02R\x02id\x12;\n\x15last_used_catalog_uid\x18\x05 \x01(\tB\x03\xe0\x41\x01H\x00R\x12lastUsedCatalogUid\x88\x01\x01\x12/\n\x0flast_used_top_k\x18\x06 \x01(\rB\x03\xe0\x41\x01H\x01R\x0clastUsedTopK\x88\x01\x01\x12@\n\x0b\x63reate_time\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x03\xe0\x41\x03R\ncreateTime\x12@\n\x0bupdate_time\x18\x08 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x03\xe0\x41\x03R\nupdateTimeB\x18\n\x16_last_used_catalog_uidB\x12\n\x10_last_used_top_k\"\xd8\x03\n\x07Message\x12\x15\n\x03uid\x18\x01 \x01(\tB\x03\xe0\x41\x03R\x03uid\x12\x1c\n\x07\x61pp_uid\x18\x02 \x01(\tB\x03\xe0\x41\x03R\x06\x61ppUid\x12.\n\x10\x63onversation_uid\x18\x03 \x01(\tB\x03\xe0\x41\x03R\x0f\x63onversationUid\x12\x1d\n\x07\x63ontent\x18\x04 \x01(\tB\x03\xe0\x41\x02R\x07\x63ontent\x12\x17\n\x04role\x18\x05 \x01(\tB\x03\xe0\x41\x02R\x04role\x12=\n\x04type\x18\x06 \x01(\x0e\x32$.app.app.v1alpha.Message.MessageTypeB\x03\xe0\x41\x02R\x04type\x12@\n\x0b\x63reate_time\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x03\xe0\x41\x03R\ncreateTime\x12@\n\x0bupdate_time\x18\x08 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x03\xe0\x41\x03R\nupdateTime\x12)\n\x0emsg_sender_uid\x18\t \x01(\tB\x03\xe0\x41\x03R\x0cmsgSenderUid\"B\n\x0bMessageType\x12\x1c\n\x18MESSAGE_TYPE_UNSPECIFIED\x10\x00\x12\x15\n\x11MESSAGE_TYPE_TEXT\x10\x01\"\x8d\x01\n\x19\x43reateConversationRequest\x12&\n\x0cnamespace_id\x18\x01 \x01(\tB\x03\xe0\x41\x02R\x0bnamespaceId\x12\x1a\n\x06\x61pp_id\x18\x02 \x01(\tB\x03\xe0\x41\x02R\x05\x61ppId\x12,\n\x0f\x63onversation_id\x18\x03 \x01(\tB\x03\xe0\x41\x02R\x0e\x63onversationId\"d\n\x1a\x43reateConversationResponse\x12\x46\n\x0c\x63onversation\x18\x01 \x01(\x0b\x32\x1d.app.app.v1alpha.ConversationB\x03\xe0\x41\x03R\x0c\x63onversation\"\x9e\x02\n\x18ListConversationsRequest\x12&\n\x0cnamespace_id\x18\x01 \x01(\tB\x03\xe0\x41\x02R\x0bnamespaceId\x12\x1a\n\x06\x61pp_id\x18\x02 \x01(\tB\x03\xe0\x41\x02R\x05\x61ppId\x12 \n\tpage_size\x18\x03 \x01(\x05\x42\x03\xe0\x41\x01R\x08pageSize\x12\"\n\npage_token\x18\x04 \x01(\tB\x03\xe0\x41\x01R\tpageToken\x12.\n\x10\x63onversation_uid\x18\x05 \x01(\tB\x03\xe0\x41\x01R\x0f\x63onversationUid\x12,\n\x0f\x63onversation_id\x18\x06 \x01(\tB\x03\xe0\x41\x01R\x0e\x63onversationId\x12\x1a\n\x06if_all\x18\x07 \x01(\x08\x42\x03\xe0\x41\x01R\x05ifAll\"\xb6\x01\n\x19ListConversationsResponse\x12H\n\rconversations\x18\x01 \x03(\x0b\x32\x1d.app.app.v1alpha.ConversationB\x03\xe0\x41\x03R\rconversations\x12+\n\x0fnext_page_token\x18\x02 \x01(\tB\x03\xe0\x41\x03R\rnextPageToken\x12\"\n\ntotal_size\x18\x03 \x01(\x05\x42\x03\xe0\x41\x03R\ttotalSize\"\xf6\x02\n\x19UpdateConversationRequest\x12!\n\x0cnamespace_id\x18\x01 \x01(\tR\x0bnamespaceId\x12\x1a\n\x06\x61pp_id\x18\x02 \x01(\tB\x03\xe0\x41\x02R\x05\x61ppId\x12,\n\x0f\x63onversation_id\x18\x03 \x01(\tB\x03\xe0\x41\x02R\x0e\x63onversationId\x12\x38\n\x13new_conversation_id\x18\x04 \x01(\tB\x03\xe0\x41\x01H\x00R\x11newConversationId\x88\x01\x01\x12;\n\x15last_used_catalog_uid\x18\x05 \x01(\tB\x03\xe0\x41\x01H\x01R\x12lastUsedCatalogUid\x88\x01\x01\x12/\n\x0flast_used_top_k\x18\x06 \x01(\rB\x03\xe0\x41\x01H\x02R\x0clastUsedTopK\x88\x01\x01\x42\x16\n\x14_new_conversation_idB\x18\n\x16_last_used_catalog_uidB\x12\n\x10_last_used_top_k\"d\n\x1aUpdateConversationResponse\x12\x46\n\x0c\x63onversation\x18\x01 \x01(\x0b\x32\x1d.app.app.v1alpha.ConversationB\x03\xe0\x41\x03R\x0c\x63onversation\"\x8d\x01\n\x19\x44\x65leteConversationRequest\x12&\n\x0cnamespace_id\x18\x01 \x01(\tB\x03\xe0\x41\x02R\x0bnamespaceId\x12\x1a\n\x06\x61pp_id\x18\x02 \x01(\tB\x03\xe0\x41\x02R\x05\x61ppId\x12,\n\x0f\x63onversation_id\x18\x03 \x01(\tB\x03\xe0\x41\x02R\x0e\x63onversationId\"\x1c\n\x1a\x44\x65leteConversationResponse\"\xff\x01\n\x14\x43reateMessageRequest\x12&\n\x0cnamespace_id\x18\x01 \x01(\tB\x03\xe0\x41\x02R\x0bnamespaceId\x12\x1a\n\x06\x61pp_id\x18\x02 \x01(\tB\x03\xe0\x41\x02R\x05\x61ppId\x12,\n\x0f\x63onversation_id\x18\x03 \x01(\tB\x03\xe0\x41\x02R\x0e\x63onversationId\x12\x1d\n\x07\x63ontent\x18\x04 \x01(\tB\x03\xe0\x41\x02R\x07\x63ontent\x12\x17\n\x04role\x18\x05 \x01(\tB\x03\xe0\x41\x02R\x04role\x12=\n\x04type\x18\x06 \x01(\x0e\x32$.app.app.v1alpha.Message.MessageTypeB\x03\xe0\x41\x02R\x04type\"K\n\x15\x43reateMessageResponse\x12\x32\n\x07message\x18\x01 \x01(\x0b\x32\x18.app.app.v1alpha.MessageR\x07message\"\xd5\x01\n\x14MessageSenderProfile\x12)\n\x0emsg_sender_uid\x18\x01 \x01(\tB\x03\xe0\x41\x03R\x0cmsgSenderUid\x12\'\n\rmsg_sender_id\x18\x02 \x01(\tB\x03\xe0\x41\x03R\x0bmsgSenderId\x12+\n\x0c\x64isplay_name\x18\x03 \x01(\tB\x03\xe0\x41\x03H\x00R\x0b\x64isplayName\x88\x01\x01\x12 \n\x06\x61vatar\x18\x04 \x01(\tB\x03\xe0\x41\x03H\x01R\x06\x61vatar\x88\x01\x01\x42\x0f\n\r_display_nameB\t\n\x07_avatar\"\xec\x02\n\x13ListMessagesRequest\x12&\n\x0cnamespace_id\x18\x01 \x01(\tB\x03\xe0\x41\x02R\x0bnamespaceId\x12\x1a\n\x06\x61pp_id\x18\x02 \x01(\tB\x03\xe0\x41\x02R\x05\x61ppId\x12,\n\x0f\x63onversation_id\x18\x03 \x01(\tB\x03\xe0\x41\x02R\x0e\x63onversationId\x12\x1e\n\x08latest_k\x18\x04 \x01(\x05\x42\x03\xe0\x41\x01R\x07latestK\x12 \n\tpage_size\x18\x05 \x01(\x05\x42\x03\xe0\x41\x03R\x08pageSize\x12\"\n\npage_token\x18\x06 \x01(\tB\x03\xe0\x41\x03R\tpageToken\x12;\n\x17include_system_messages\x18\x07 \x01(\x08\x42\x03\xe0\x41\x03R\x15includeSystemMessages\x12\x1a\n\x06if_all\x18\x08 \x01(\x08\x42\x03\xe0\x41\x01R\x05ifAll\x12$\n\x0bmessage_uid\x18\t \x01(\tB\x03\xe0\x41\x01R\nmessageUid\"\xf7\x01\n\x14ListMessagesResponse\x12\x39\n\x08messages\x18\x01 \x03(\x0b\x32\x18.app.app.v1alpha.MessageB\x03\xe0\x41\x03R\x08messages\x12+\n\x0fnext_page_token\x18\x02 \x01(\tB\x03\xe0\x41\x03R\rnextPageToken\x12\"\n\ntotal_size\x18\x03 \x01(\x05\x42\x03\xe0\x41\x03R\ttotalSize\x12S\n\x0fsender_profiles\x18\x04 \x03(\x0b\x32%.app.app.v1alpha.MessageSenderProfileB\x03\xe0\x41\x03R\x0esenderProfiles\"\xcd\x01\n\x14UpdateMessageRequest\x12&\n\x0cnamespace_id\x18\x01 \x01(\tB\x03\xe0\x41\x02R\x0bnamespaceId\x12\x1a\n\x06\x61pp_id\x18\x02 \x01(\tB\x03\xe0\x41\x02R\x05\x61ppId\x12,\n\x0f\x63onversation_id\x18\x03 \x01(\tB\x03\xe0\x41\x02R\x0e\x63onversationId\x12$\n\x0bmessage_uid\x18\x04 \x01(\tB\x03\xe0\x41\x02R\nmessageUid\x12\x1d\n\x07\x63ontent\x18\x05 \x01(\tB\x03\xe0\x41\x02R\x07\x63ontent\"P\n\x15UpdateMessageResponse\x12\x37\n\x07message\x18\x01 \x01(\x0b\x32\x18.app.app.v1alpha.MessageB\x03\xe0\x41\x03R\x07message\"\xae\x01\n\x14\x44\x65leteMessageRequest\x12&\n\x0cnamespace_id\x18\x01 \x01(\tB\x03\xe0\x41\x02R\x0bnamespaceId\x12\x1a\n\x06\x61pp_id\x18\x02 \x01(\tB\x03\xe0\x41\x02R\x05\x61ppId\x12,\n\x0f\x63onversation_id\x18\x03 \x01(\tB\x03\xe0\x41\x02R\x0e\x63onversationId\x12$\n\x0bmessage_uid\x18\x04 \x01(\tB\x03\xe0\x41\x02R\nmessageUid\"\x17\n\x15\x44\x65leteMessageResponse\"\xe8\x01\n\x0b\x43hatRequest\x12&\n\x0cnamespace_id\x18\x01 \x01(\tB\x03\xe0\x41\x02R\x0bnamespaceId\x12\x1a\n\x06\x61pp_id\x18\x02 \x01(\tB\x03\xe0\x41\x02R\x05\x61ppId\x12\"\n\ncatalog_id\x18\x03 \x01(\tB\x03\xe0\x41\x02R\tcatalogId\x12.\n\x10\x63onversation_uid\x18\x04 \x01(\tB\x03\xe0\x41\x02R\x0f\x63onversationUid\x12\x1d\n\x07message\x18\x05 \x01(\tB\x03\xe0\x41\x02R\x07message\x12\x18\n\x05top_k\x18\x06 \x01(\rH\x00R\x04topK\x88\x01\x01\x42\x08\n\x06_top_k\"\x8f\x01\n\x0c\x43hatResponse\x12\x36\n\x07outputs\x18\x01 \x03(\x0b\x32\x17.google.protobuf.StructB\x03\xe0\x41\x03R\x07outputs\x12G\n\x06\x63hunks\x18\x02 \x03(\x0b\x32*.artifact.artifact.v1alpha.SimilarityChunkB\x03\xe0\x41\x03R\x06\x63hunksB\xc4\x01\n\x13\x63om.app.app.v1alphaB\x11\x43onversationProtoP\x01Z<github.com/instill-ai/protogen-go/app/app/v1alpha;appv1alpha\xa2\x02\x03\x41\x41X\xaa\x02\x0f\x41pp.App.V1alpha\xca\x02\x0f\x41pp\\App\\V1alpha\xe2\x02\x1b\x41pp\\App\\V1alpha\\GPBMetadata\xea\x02\x11\x41pp::App::V1alphab\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'app.app.v1alpha.conversation_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\023com.app.app.v1alphaB\021ConversationProtoP\001Z<github.com/instill-ai/protogen-go/app/app/v1alpha;appv1alpha\242\002\003AAX\252\002\017App.App.V1alpha\312\002\017App\\App\\V1alpha\342\002\033App\\App\\V1alpha\\GPBMetadata\352\002\021App::App::V1alpha'
  _CONVERSATION.fields_by_name['uid']._options = None
  _CONVERSATION.fields_by_name['uid']._serialized_options = b'\340A\003'
  _CONVERSATION.fields_by_name['namespace_id']._options = None
  _CONVERSATION.fields_by_name['namespace_id']._serialized_options = b'\340A\002'
  _CONVERSATION.fields_by_name['app_id']._options = None
  _CONVERSATION.fields_by_name['app_id']._serialized_options = b'\340A\002'
  _CONVERSATION.fields_by_name['id']._options = None
  _CONVERSATION.fields_by_name['id']._serialized_options = b'\340A\002'
  _CONVERSATION.fields_by_name['last_used_catalog_uid']._options = None
  _CONVERSATION.fields_by_name['last_used_catalog_uid']._serialized_options = b'\340A\001'
  _CONVERSATION.fields_by_name['last_used_top_k']._options = None
  _CONVERSATION.fields_by_name['last_used_top_k']._serialized_options = b'\340A\001'
  _CONVERSATION.fields_by_name['create_time']._options = None
  _CONVERSATION.fields_by_name['create_time']._serialized_options = b'\340A\003'
  _CONVERSATION.fields_by_name['update_time']._options = None
  _CONVERSATION.fields_by_name['update_time']._serialized_options = b'\340A\003'
  _MESSAGE.fields_by_name['uid']._options = None
  _MESSAGE.fields_by_name['uid']._serialized_options = b'\340A\003'
  _MESSAGE.fields_by_name['app_uid']._options = None
  _MESSAGE.fields_by_name['app_uid']._serialized_options = b'\340A\003'
  _MESSAGE.fields_by_name['conversation_uid']._options = None
  _MESSAGE.fields_by_name['conversation_uid']._serialized_options = b'\340A\003'
  _MESSAGE.fields_by_name['content']._options = None
  _MESSAGE.fields_by_name['content']._serialized_options = b'\340A\002'
  _MESSAGE.fields_by_name['role']._options = None
  _MESSAGE.fields_by_name['role']._serialized_options = b'\340A\002'
  _MESSAGE.fields_by_name['type']._options = None
  _MESSAGE.fields_by_name['type']._serialized_options = b'\340A\002'
  _MESSAGE.fields_by_name['create_time']._options = None
  _MESSAGE.fields_by_name['create_time']._serialized_options = b'\340A\003'
  _MESSAGE.fields_by_name['update_time']._options = None
  _MESSAGE.fields_by_name['update_time']._serialized_options = b'\340A\003'
  _MESSAGE.fields_by_name['msg_sender_uid']._options = None
  _MESSAGE.fields_by_name['msg_sender_uid']._serialized_options = b'\340A\003'
  _CREATECONVERSATIONREQUEST.fields_by_name['namespace_id']._options = None
  _CREATECONVERSATIONREQUEST.fields_by_name['namespace_id']._serialized_options = b'\340A\002'
  _CREATECONVERSATIONREQUEST.fields_by_name['app_id']._options = None
  _CREATECONVERSATIONREQUEST.fields_by_name['app_id']._serialized_options = b'\340A\002'
  _CREATECONVERSATIONREQUEST.fields_by_name['conversation_id']._options = None
  _CREATECONVERSATIONREQUEST.fields_by_name['conversation_id']._serialized_options = b'\340A\002'
  _CREATECONVERSATIONRESPONSE.fields_by_name['conversation']._options = None
  _CREATECONVERSATIONRESPONSE.fields_by_name['conversation']._serialized_options = b'\340A\003'
  _LISTCONVERSATIONSREQUEST.fields_by_name['namespace_id']._options = None
  _LISTCONVERSATIONSREQUEST.fields_by_name['namespace_id']._serialized_options = b'\340A\002'
  _LISTCONVERSATIONSREQUEST.fields_by_name['app_id']._options = None
  _LISTCONVERSATIONSREQUEST.fields_by_name['app_id']._serialized_options = b'\340A\002'
  _LISTCONVERSATIONSREQUEST.fields_by_name['page_size']._options = None
  _LISTCONVERSATIONSREQUEST.fields_by_name['page_size']._serialized_options = b'\340A\001'
  _LISTCONVERSATIONSREQUEST.fields_by_name['page_token']._options = None
  _LISTCONVERSATIONSREQUEST.fields_by_name['page_token']._serialized_options = b'\340A\001'
  _LISTCONVERSATIONSREQUEST.fields_by_name['conversation_uid']._options = None
  _LISTCONVERSATIONSREQUEST.fields_by_name['conversation_uid']._serialized_options = b'\340A\001'
  _LISTCONVERSATIONSREQUEST.fields_by_name['conversation_id']._options = None
  _LISTCONVERSATIONSREQUEST.fields_by_name['conversation_id']._serialized_options = b'\340A\001'
  _LISTCONVERSATIONSREQUEST.fields_by_name['if_all']._options = None
  _LISTCONVERSATIONSREQUEST.fields_by_name['if_all']._serialized_options = b'\340A\001'
  _LISTCONVERSATIONSRESPONSE.fields_by_name['conversations']._options = None
  _LISTCONVERSATIONSRESPONSE.fields_by_name['conversations']._serialized_options = b'\340A\003'
  _LISTCONVERSATIONSRESPONSE.fields_by_name['next_page_token']._options = None
  _LISTCONVERSATIONSRESPONSE.fields_by_name['next_page_token']._serialized_options = b'\340A\003'
  _LISTCONVERSATIONSRESPONSE.fields_by_name['total_size']._options = None
  _LISTCONVERSATIONSRESPONSE.fields_by_name['total_size']._serialized_options = b'\340A\003'
  _UPDATECONVERSATIONREQUEST.fields_by_name['app_id']._options = None
  _UPDATECONVERSATIONREQUEST.fields_by_name['app_id']._serialized_options = b'\340A\002'
  _UPDATECONVERSATIONREQUEST.fields_by_name['conversation_id']._options = None
  _UPDATECONVERSATIONREQUEST.fields_by_name['conversation_id']._serialized_options = b'\340A\002'
  _UPDATECONVERSATIONREQUEST.fields_by_name['new_conversation_id']._options = None
  _UPDATECONVERSATIONREQUEST.fields_by_name['new_conversation_id']._serialized_options = b'\340A\001'
  _UPDATECONVERSATIONREQUEST.fields_by_name['last_used_catalog_uid']._options = None
  _UPDATECONVERSATIONREQUEST.fields_by_name['last_used_catalog_uid']._serialized_options = b'\340A\001'
  _UPDATECONVERSATIONREQUEST.fields_by_name['last_used_top_k']._options = None
  _UPDATECONVERSATIONREQUEST.fields_by_name['last_used_top_k']._serialized_options = b'\340A\001'
  _UPDATECONVERSATIONRESPONSE.fields_by_name['conversation']._options = None
  _UPDATECONVERSATIONRESPONSE.fields_by_name['conversation']._serialized_options = b'\340A\003'
  _DELETECONVERSATIONREQUEST.fields_by_name['namespace_id']._options = None
  _DELETECONVERSATIONREQUEST.fields_by_name['namespace_id']._serialized_options = b'\340A\002'
  _DELETECONVERSATIONREQUEST.fields_by_name['app_id']._options = None
  _DELETECONVERSATIONREQUEST.fields_by_name['app_id']._serialized_options = b'\340A\002'
  _DELETECONVERSATIONREQUEST.fields_by_name['conversation_id']._options = None
  _DELETECONVERSATIONREQUEST.fields_by_name['conversation_id']._serialized_options = b'\340A\002'
  _CREATEMESSAGEREQUEST.fields_by_name['namespace_id']._options = None
  _CREATEMESSAGEREQUEST.fields_by_name['namespace_id']._serialized_options = b'\340A\002'
  _CREATEMESSAGEREQUEST.fields_by_name['app_id']._options = None
  _CREATEMESSAGEREQUEST.fields_by_name['app_id']._serialized_options = b'\340A\002'
  _CREATEMESSAGEREQUEST.fields_by_name['conversation_id']._options = None
  _CREATEMESSAGEREQUEST.fields_by_name['conversation_id']._serialized_options = b'\340A\002'
  _CREATEMESSAGEREQUEST.fields_by_name['content']._options = None
  _CREATEMESSAGEREQUEST.fields_by_name['content']._serialized_options = b'\340A\002'
  _CREATEMESSAGEREQUEST.fields_by_name['role']._options = None
  _CREATEMESSAGEREQUEST.fields_by_name['role']._serialized_options = b'\340A\002'
  _CREATEMESSAGEREQUEST.fields_by_name['type']._options = None
  _CREATEMESSAGEREQUEST.fields_by_name['type']._serialized_options = b'\340A\002'
  _MESSAGESENDERPROFILE.fields_by_name['msg_sender_uid']._options = None
  _MESSAGESENDERPROFILE.fields_by_name['msg_sender_uid']._serialized_options = b'\340A\003'
  _MESSAGESENDERPROFILE.fields_by_name['msg_sender_id']._options = None
  _MESSAGESENDERPROFILE.fields_by_name['msg_sender_id']._serialized_options = b'\340A\003'
  _MESSAGESENDERPROFILE.fields_by_name['display_name']._options = None
  _MESSAGESENDERPROFILE.fields_by_name['display_name']._serialized_options = b'\340A\003'
  _MESSAGESENDERPROFILE.fields_by_name['avatar']._options = None
  _MESSAGESENDERPROFILE.fields_by_name['avatar']._serialized_options = b'\340A\003'
  _LISTMESSAGESREQUEST.fields_by_name['namespace_id']._options = None
  _LISTMESSAGESREQUEST.fields_by_name['namespace_id']._serialized_options = b'\340A\002'
  _LISTMESSAGESREQUEST.fields_by_name['app_id']._options = None
  _LISTMESSAGESREQUEST.fields_by_name['app_id']._serialized_options = b'\340A\002'
  _LISTMESSAGESREQUEST.fields_by_name['conversation_id']._options = None
  _LISTMESSAGESREQUEST.fields_by_name['conversation_id']._serialized_options = b'\340A\002'
  _LISTMESSAGESREQUEST.fields_by_name['latest_k']._options = None
  _LISTMESSAGESREQUEST.fields_by_name['latest_k']._serialized_options = b'\340A\001'
  _LISTMESSAGESREQUEST.fields_by_name['page_size']._options = None
  _LISTMESSAGESREQUEST.fields_by_name['page_size']._serialized_options = b'\340A\003'
  _LISTMESSAGESREQUEST.fields_by_name['page_token']._options = None
  _LISTMESSAGESREQUEST.fields_by_name['page_token']._serialized_options = b'\340A\003'
  _LISTMESSAGESREQUEST.fields_by_name['include_system_messages']._options = None
  _LISTMESSAGESREQUEST.fields_by_name['include_system_messages']._serialized_options = b'\340A\003'
  _LISTMESSAGESREQUEST.fields_by_name['if_all']._options = None
  _LISTMESSAGESREQUEST.fields_by_name['if_all']._serialized_options = b'\340A\001'
  _LISTMESSAGESREQUEST.fields_by_name['message_uid']._options = None
  _LISTMESSAGESREQUEST.fields_by_name['message_uid']._serialized_options = b'\340A\001'
  _LISTMESSAGESRESPONSE.fields_by_name['messages']._options = None
  _LISTMESSAGESRESPONSE.fields_by_name['messages']._serialized_options = b'\340A\003'
  _LISTMESSAGESRESPONSE.fields_by_name['next_page_token']._options = None
  _LISTMESSAGESRESPONSE.fields_by_name['next_page_token']._serialized_options = b'\340A\003'
  _LISTMESSAGESRESPONSE.fields_by_name['total_size']._options = None
  _LISTMESSAGESRESPONSE.fields_by_name['total_size']._serialized_options = b'\340A\003'
  _LISTMESSAGESRESPONSE.fields_by_name['sender_profiles']._options = None
  _LISTMESSAGESRESPONSE.fields_by_name['sender_profiles']._serialized_options = b'\340A\003'
  _UPDATEMESSAGEREQUEST.fields_by_name['namespace_id']._options = None
  _UPDATEMESSAGEREQUEST.fields_by_name['namespace_id']._serialized_options = b'\340A\002'
  _UPDATEMESSAGEREQUEST.fields_by_name['app_id']._options = None
  _UPDATEMESSAGEREQUEST.fields_by_name['app_id']._serialized_options = b'\340A\002'
  _UPDATEMESSAGEREQUEST.fields_by_name['conversation_id']._options = None
  _UPDATEMESSAGEREQUEST.fields_by_name['conversation_id']._serialized_options = b'\340A\002'
  _UPDATEMESSAGEREQUEST.fields_by_name['message_uid']._options = None
  _UPDATEMESSAGEREQUEST.fields_by_name['message_uid']._serialized_options = b'\340A\002'
  _UPDATEMESSAGEREQUEST.fields_by_name['content']._options = None
  _UPDATEMESSAGEREQUEST.fields_by_name['content']._serialized_options = b'\340A\002'
  _UPDATEMESSAGERESPONSE.fields_by_name['message']._options = None
  _UPDATEMESSAGERESPONSE.fields_by_name['message']._serialized_options = b'\340A\003'
  _DELETEMESSAGEREQUEST.fields_by_name['namespace_id']._options = None
  _DELETEMESSAGEREQUEST.fields_by_name['namespace_id']._serialized_options = b'\340A\002'
  _DELETEMESSAGEREQUEST.fields_by_name['app_id']._options = None
  _DELETEMESSAGEREQUEST.fields_by_name['app_id']._serialized_options = b'\340A\002'
  _DELETEMESSAGEREQUEST.fields_by_name['conversation_id']._options = None
  _DELETEMESSAGEREQUEST.fields_by_name['conversation_id']._serialized_options = b'\340A\002'
  _DELETEMESSAGEREQUEST.fields_by_name['message_uid']._options = None
  _DELETEMESSAGEREQUEST.fields_by_name['message_uid']._serialized_options = b'\340A\002'
  _CHATREQUEST.fields_by_name['namespace_id']._options = None
  _CHATREQUEST.fields_by_name['namespace_id']._serialized_options = b'\340A\002'
  _CHATREQUEST.fields_by_name['app_id']._options = None
  _CHATREQUEST.fields_by_name['app_id']._serialized_options = b'\340A\002'
  _CHATREQUEST.fields_by_name['catalog_id']._options = None
  _CHATREQUEST.fields_by_name['catalog_id']._serialized_options = b'\340A\002'
  _CHATREQUEST.fields_by_name['conversation_uid']._options = None
  _CHATREQUEST.fields_by_name['conversation_uid']._serialized_options = b'\340A\002'
  _CHATREQUEST.fields_by_name['message']._options = None
  _CHATREQUEST.fields_by_name['message']._serialized_options = b'\340A\002'
  _CHATRESPONSE.fields_by_name['outputs']._options = None
  _CHATRESPONSE.fields_by_name['outputs']._serialized_options = b'\340A\003'
  _CHATRESPONSE.fields_by_name['chunks']._options = None
  _CHATRESPONSE.fields_by_name['chunks']._serialized_options = b'\340A\003'
  _globals['_CONVERSATION']._serialized_start=191
  _globals['_CONVERSATION']._serialized_end=605
  _globals['_MESSAGE']._serialized_start=608
  _globals['_MESSAGE']._serialized_end=1080
  _globals['_MESSAGE_MESSAGETYPE']._serialized_start=1014
  _globals['_MESSAGE_MESSAGETYPE']._serialized_end=1080
  _globals['_CREATECONVERSATIONREQUEST']._serialized_start=1083
  _globals['_CREATECONVERSATIONREQUEST']._serialized_end=1224
  _globals['_CREATECONVERSATIONRESPONSE']._serialized_start=1226
  _globals['_CREATECONVERSATIONRESPONSE']._serialized_end=1326
  _globals['_LISTCONVERSATIONSREQUEST']._serialized_start=1329
  _globals['_LISTCONVERSATIONSREQUEST']._serialized_end=1615
  _globals['_LISTCONVERSATIONSRESPONSE']._serialized_start=1618
  _globals['_LISTCONVERSATIONSRESPONSE']._serialized_end=1800
  _globals['_UPDATECONVERSATIONREQUEST']._serialized_start=1803
  _globals['_UPDATECONVERSATIONREQUEST']._serialized_end=2177
  _globals['_UPDATECONVERSATIONRESPONSE']._serialized_start=2179
  _globals['_UPDATECONVERSATIONRESPONSE']._serialized_end=2279
  _globals['_DELETECONVERSATIONREQUEST']._serialized_start=2282
  _globals['_DELETECONVERSATIONREQUEST']._serialized_end=2423
  _globals['_DELETECONVERSATIONRESPONSE']._serialized_start=2425
  _globals['_DELETECONVERSATIONRESPONSE']._serialized_end=2453
  _globals['_CREATEMESSAGEREQUEST']._serialized_start=2456
  _globals['_CREATEMESSAGEREQUEST']._serialized_end=2711
  _globals['_CREATEMESSAGERESPONSE']._serialized_start=2713
  _globals['_CREATEMESSAGERESPONSE']._serialized_end=2788
  _globals['_MESSAGESENDERPROFILE']._serialized_start=2791
  _globals['_MESSAGESENDERPROFILE']._serialized_end=3004
  _globals['_LISTMESSAGESREQUEST']._serialized_start=3007
  _globals['_LISTMESSAGESREQUEST']._serialized_end=3371
  _globals['_LISTMESSAGESRESPONSE']._serialized_start=3374
  _globals['_LISTMESSAGESRESPONSE']._serialized_end=3621
  _globals['_UPDATEMESSAGEREQUEST']._serialized_start=3624
  _globals['_UPDATEMESSAGEREQUEST']._serialized_end=3829
  _globals['_UPDATEMESSAGERESPONSE']._serialized_start=3831
  _globals['_UPDATEMESSAGERESPONSE']._serialized_end=3911
  _globals['_DELETEMESSAGEREQUEST']._serialized_start=3914
  _globals['_DELETEMESSAGEREQUEST']._serialized_end=4088
  _globals['_DELETEMESSAGERESPONSE']._serialized_start=4090
  _globals['_DELETEMESSAGERESPONSE']._serialized_end=4113
  _globals['_CHATREQUEST']._serialized_start=4116
  _globals['_CHATREQUEST']._serialized_end=4348
  _globals['_CHATRESPONSE']._serialized_start=4351
  _globals['_CHATRESPONSE']._serialized_end=4494
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class _Task:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _TaskEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_Task.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    TASK_UNSPECIFIED: _Task.ValueType  # 0
    """Unspecified."""
    TASK_CLASSIFICATION: _Task.ValueType  # 1
    """Image Classification - classify images into predefined categories."""
    TASK_DETECTION: _Task.ValueType  # 2
    """Object Detection - detect and localize multiple objects in images."""
    TASK_KEYPOINT: _Task.ValueType  # 3
    """Keypoint Detection - detect and localize multiple keypoints of objects in images."""
    TASK_OCR: _Task.ValueType  # 4
    """OCR (Optical Character Recognition) - detect and recognize text in images."""
    TASK_INSTANCE_SEGMENTATION: _Task.ValueType  # 5
    """Instance Segmentation - detect, localize and delineate multiple objects in images."""
    TASK_SEMANTIC_SEGMENTATION: _Task.ValueType  # 6
    """Semantic Segmentation - classify image pixels into predefined categories."""
    TASK_TEXT_TO_IMAGE: _Task.ValueType  # 7
    """Text to Image - generate images from input text prompts."""
    TASK_IMAGE_TO_IMAGE: _Task.ValueType  # 11
    """Image to Image - generate an image from another image."""
    TASK_EMBEDDING: _Task.ValueType  # 12
    """Embedding - generate an embedding (a representation as coordinates) from a multimodal input."""
    TASK_SPEECH_RECOGNITION: _Task.ValueType  # 13
    """Speech Recognition - transcribe the words in an audio input."""
    TASK_CHAT: _Task.ValueType  # 14
    """Conversational Text Generation - generate text as responses to a dialog input."""
    TASK_COMPLETION: _Task.ValueType  # 15
    """Completion Text Generation - generate text following the input prompt."""
    TASK_CUSTOM: _Task.ValueType  # 16
    """Custom - custom task type for free form input/output."""

class Task(_Task, metaclass=_TaskEnumTypeWrapper):
    """Task enumerates the AI task that a model is designed to solve."""

TASK_UNSPECIFIED: Task.ValueType  # 0
"""Unspecified."""
TASK_CLASSIFICATION: Task.ValueType  # 1
"""Image Classification - classify images into predefined categories."""
TASK_DETECTION: Task.ValueType  # 2
"""Object Detection - detect and localize multiple objects in images."""
TASK_KEYPOINT: Task.ValueType  # 3
"""Keypoint Detection - detect and localize multiple keypoints of objects in images."""
TASK_OCR: Task.ValueType  # 4
"""OCR (Optical Character Recognition) - detect and recognize text in images."""
TASK_INSTANCE_SEGMENTATION: Task.ValueType  # 5
"""Instance Segmentation - detect, localize and delineate multiple objects in images."""
TASK_SEMANTIC_SEGMENTATION: Task.ValueType  # 6
"""Semantic Segmentation - classify image pixels into predefined categories."""
TASK_TEXT_TO_IMAGE: Task.ValueType  # 7
"""Text to Image - generate images from input text prompts."""
TASK_IMAGE_TO_IMAGE: Task.ValueType  # 11
"""Image to Image - generate an image from another image."""
TASK_EMBEDDING: Task.ValueType  # 12
"""Embedding - generate an embedding (a representation as coordinates) from a multimodal input."""
TASK_SPEECH_RECOGNITION: Task.ValueType  # 13
"""Speech Recognition - transcribe the words in an audio input."""
TASK_CHAT: Task.ValueType  # 14
"""Conversational Text Generation - generate text as responses to a dialog input."""
TASK_COMPLETION: Task.ValueType  # 15
"""Completion Text Generation - generate text following the input prompt."""
TASK_CUSTOM: Task.ValueType  # 16
"""Custom - custom task type for free form input/output."""
global___Task = Task
